/*
 Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("specialchar","el",{euro:"Σύμβολο Ευρώ",lsquo:"Αριστερός χαρακτήρας μονού εισαγωγικού",rsquo:"Δεξιός χαρακτήρας μονού εισαγωγικού",ldquo:"Αριστερός χαρακτήρας διπλού εισαγωγικού",rdquo:"Δεξιός χαρακτήρας διπλού εισαγωγικού",ndash:"Παύλα en",mdash:"Παύλα em",iexcl:"Ανάποδο θαυμαστικό",cent:"Σύμβολο Σεντ",pound:"Σύμβολο λίρας",curren:"Σύμβολο συναλλαγματικής μονάδας",yen:"Σύμβολο Γιέν",brvbar:"Σπασμένη μπάρα",sect:"Σύμβολο τμήματος",uml:"Διαίρεση",copy:"Σύμβολο πνευματικών δικαιωμάτων",
ordf:"Feminine ordinal indicator",laquo:"Αριστερός χαρακτήρας διπλού εισαγωγικού",not:"Δεν έχει υπογράψει ",reg:"Εγγεγραμμένο σημάδι ",macr:"Macron",deg:"Εγγεγραμμένο σημάδι ",sup2:"Superscript two",sup3:"Superscript three",acute:"Οξεία προφορά ",micro:"Micro σημάδι ",para:"Micro σημάδι ",middot:"Μέση τελεια",cedil:"Υποστιγμή ",sup1:"Superscript one",ordm:"Αρσενικος τακτικός δείκτης ",raquo:"Δεξιος χαρακτήρας διπλού εισαγωγικού",frac14:"Χυδαίο κλάσμα του ενός τετάρτου ",frac12:"Χυδαίο κλάσμα το ήμισυ ",
frac34:"Χυδαίο κλάσμα τρία τέταρτα ",iquest:"Ανάποδο θαυμαστικό",Agrave:"Λατινικο κεφαλαίο γράμμα Α με βαρεία ",Aacute:"Λατινικο κεφαλαίο γράμμα Α με οξεία ",Acirc:"Λατινικο Α κεφαλαίο γράμμα με περισπωμένη ",Atilde:"Λατινικο κεφαλαίο γράμμα Α με περισπωμένη ",Auml:"Λατινικο κεφαλαίο γράμμα Α με διαλυτικά ",Aring:"Λατινικο κεφαλαίο γράμμα Α με δακτύλιο επάνω ",AElig:"Λατινικό γράμμα CAPITAL Æ",Ccedil:"Λατινικο κεφαλαίο γράμμα C με υπογεγραμμένη",Egrave:"Λατινικο Ε κεφαλαίο γράμμα με βαρεία ",Eacute:"Λατινική Ε κεφαλαίο γράμμα με οξεία ",
Ecirc:"Λατινικο Ε κεφαλαίο γράμμα με περισπωμένη ",Euml:"Λατινικο Ε κεφαλαίο γράμμα με διαλυτικά ",Igrave:"Λατινικο κεφαλαίο γράμμα I με βαρεία ",Iacute:"Λατινικο κεφαλαίο γράμμα I με οξεία ",Icirc:"Λατινικο I κεφαλαίο γράμμα με περισπωμένη ",Iuml:"Λατινικο κεφαλαίο γράμμα I με διαλυτικά ",ETH:"Λατινικο κεφαλαίο γράμμα Eth",Ntilde:"Λατινικο κεφαλαίο γράμμα Ν με περισπωμένη ",Ograve:"Λατινικο κεφαλαίο γράμμα Ο με βαρεία ",Oacute:"Λατινικο κεφαλαίο γράμμα Ο με οξεία ",Ocirc:"Λατινικο Ο κεφαλαίο γράμμα με περισπωμένη ",
Otilde:"Λατινικο κεφαλαίο γράμμα Ο με περισπωμένη ",Ouml:"Λατινικο κεφαλαίο γράμμα Ο με διαλυτικά ",times:"Σύμβολο πολλαπλασιασμού ",Oslash:"Λατινικο κεφαλαίο γράμμα O με διαδρομη",Ugrave:"Λατινικο κεφαλαίο γράμμα U με βαρεία ",Uacute:"Λατινικο κεφαλαίο γράμμα U με οξεία ",Ucirc:"Λατινικο U κεφαλαίο γράμμα με περισπωμένη ",Uuml:"Λατινικο κεφαλαίο γράμμα U με διαλυτικά ",Yacute:"Λατινικο κεφαλαίο γράμμα Y με οξεία ",THORN:"Λατινικο Thorn κεφαλαίο γράμμα ",szlig:"Λατινική μικρό γράμμα απότομο s ",agrave:"Λατινικο μικρό γράμμα Α με βαρεία ",
aacute:"Λατινικο μικρό γράμμα α με οξεία ",acirc:"Λατινικο μικρό γράμμα α με περισπωμένη ",atilde:"Λατινικο μικρό γράμμα α με περισπωμένη ",auml:"Λατινικο μικρό γράμμα α με διαλυτικά ",aring:"Λατινικο μικρό γράμμα α με δακτύλιο πάνω ",aelig:"Λατινικο μικρό γράμμα æ",ccedil:"Λατινικο μικρό γράμμα c με υπογεγραμμένη ",egrave:"Λατινικο μικρό γράμμα ε με βαρεία ",eacute:"Λατινικο μικρό γράμμα ε με οξεία ",ecirc:"Λατινική μικρό γράμμα ε με περισπωμένη ",euml:"Λατινικο μικρό γράμμα ε με διαλυτικά ",igrave:"Λατινικο μικρό γράμμα i με βαρεία ",
iacute:"Λατινική μικρό γράμμα i με οξεία ",icirc:"Λατινικο μικρό γράμμα i με περισπωμένη",iuml:"Λατινικο μικρό γράμμα i με διαλυτικά ",eth:"Λατινικο μικρό γράμμα eth ",ntilde:"Λατινικο μικρό γράμμα n με περισπωμένη ",ograve:"Λατινικο μικρό γράμμα ο με βαρεία ",oacute:"Λατινικο μικρό γράμμα ο με οξεία ",ocirc:"Λατινικό πεζό γράμμα o με περισπωμένη ",otilde:"Λατινική μικρό γράμμα ο με περισπωμένη ",ouml:"Λατινική μικρό γράμμα ο με διαλυτικά ",divide:"Σύμβολο διαίρεσης",oslash:"Λατινική μικρό γράμμα ο με περισπωμένη ",
ugrave:"Λατινικο μικρό γράμμα u  με βαρεία ",uacute:"Λατινικο μικρό γράμμα u  με οξεία ",ucirc:"Λατινικο μικρό γράμμα u  με περισπωμένη ",uuml:"Λατινικο μικρό γράμμα u  με διαλυτικά ",yacute:"Λατινικο μικρό γράμμα y με οξεία ",thorn:"Λατινικο μικρό γράμμα thorn",yuml:"Λατινικο μικρό γράμμα y με διαλυτικά ",OElig:"Λατινική κεφαλαίο λογόγραμμα ΟΕ ",oelig:"Λατινική μικρό λογόγραμμα oe ",372:"Λατινικο W κεφαλαίο γράμμα με περισπωμένη ",374:"Λατινικο Y κεφαλαίο γράμμα με περισπωμένη ",373:"Λατινικο μικρό γράμμα w με περισπωμένη ",
375:"Λατινικο μικρό γράμμα y με περισπωμένη ",sbquo:"Ενιαίο χαμηλο -9 εισαγωγικό ",8219:"Ενιαίο υψηλο ανεστραμμένηο -9 εισαγωγικό ",bdquo:"Διπλό χαμηλό -9 εισαγωγικό ",hellip:"Οριζόντια αποσιωπητικά ",trade:"Σύμβολο Εμπορικόυ Κατατεθέν",9658:"Μαύρο δείχνει προς τα δεξιά ",bull:"Κουκκίδα ",rarr:"Προς τα δεξιά ",rArr:"Προς τα δεξιά ",hArr:"Αριστερά Δεξιά διπλό βέλος ",diams:"Μαύρο διαμάντι",asymp:"Σχεδόν ίση με "});