{% load static %}

<!-- Load CSS -->

    <link rel="stylesheet" type="text/css" href="{% static 'css/style_default.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'css/lightbox.css' %}">

    <!-- Load JS -->

    <script src="{% static 'js/jquery-1.7.2.min.js' %}"></script>
    <script src="{% static 'js/lightbox.js' %}"></script>
