{% load static %}

    <!-- Load CSS -->

    <link rel="stylesheet" type="text/css" href="{% static 'css/default3/bootstrap.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'css/default3/bootstrap-responsive.css' %}">
    <!--<link rel="stylesheet" type="text/css" href="{% static 'css/default3/font-awesome.css' %}">-->
    <link rel="stylesheet" type="text/css" href="{% static 'css/default3/bootswatch.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'css/lightbox.css' %}">

    <!-- Load JS -->
    <!--<script src="{% static 'js/jquery-1.7.2.min.js' %}">-->
    <script src="{% static 'js/default3/jquery_002.js' %}"></script>
    <script src="{% static 'js/default3/jquery.js' %}"></script>
    <script src="{% static 'js/lightbox.js' %}"></script>

    <script src="{% static 'js/default3/bootstrap.js' %}"></script>
    <script src="{% static 'js/default3/bootswatch.js' %}"></script>
